/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.integration.animation_motion.osgi;

import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.robokind.api.common.osgi.ServiceClassListener;
import org.robokind.api.motion.Robot;
import org.robokind.integration.animation_motion.AnimationMotionUtils;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class AnimationRobotMonitor extends ServiceClassListener<Robot>{
    private final static Logger theLogger = Logger.getLogger(AnimationRobotMonitor.class.getName());
    private Map<Robot,ServiceRegistration[]> myRegistrationMap;
    private BundleContext myContext;
    
    public AnimationRobotMonitor(BundleContext context, String filter){
        super(Robot.class, context, filter);
        if(context == null){
            throw new NullPointerException();
        }
        myContext = context;
        myRegistrationMap = new HashMap<Robot, ServiceRegistration[]>();
    }
    
    @Override
    protected void addService(Robot t) {
        ServiceRegistration[] regs =
                AnimationMotionUtils.registerAnimationEditingComponents(
                        myContext, t);
        if(regs == null){
            return;
        }
        myRegistrationMap.put(t, regs);
    }

    @Override
    protected void removeService(Robot t) {
        ServiceRegistration[] regs = myRegistrationMap.remove(t);
        if(regs == null){
            return;
        }
        for(ServiceRegistration reg : regs){
            if(reg == null){
                continue;
            }
            try{
                reg.unregister();
            }catch(IllegalStateException ex){
                theLogger.log(Level.INFO, 
                        "Service already unregistered, no need to unregister.");
            }
        }
    }
}
